# Sample synthesis script for use with Synopsys Design Compiler
# Uses the Faraday 180nm library (compatible with UMC foundry)

# Set up initial search paths and libraries
set search_path [list . ${synopsys_root}/libraries/syn ${synopsys_root}/dw/syn_ver ${synopsys_root}/dw/sim_ver "/tools/synopsys/" ]
# Use the Faraday 180nm standard cell library, typical case behaviour
set link_library  { * "fsa0m_a_generic_core_tc.db"}
set physical_library ""
set target_library  {"fsa0m_a_generic_core_tc.db"}
set symbol_library  "fsa0m_a_generic_core_tc.sdb"
set synthetic_library  ""

# Clear the workspace to start
remove_design -designs
# Read in the verilog code - modify to use the input file to be synth'ed
set TOP {filter_serial_21}
read_verilog {$TOP.v}
current_design 

# link the design to the current library, and make names unique
# not required for simple designs, more for hierarchical designs
link
uniquify

# Do basic check of the design
check_design 

# Set up the clock for the system - only period constraint
create_clock -name clk -period 10 -add [get_ports clk]

# try to minimize area
#set_max_area 0

# automatic removal of constant FFs
set compile_seqmap_propagate_constants true

check_timing

compile
#compile -ungroup_all
#compile -map_effort high 

report_hierarchy > $TOP.hier
report_area > $TOP.area
report_timing > $TOP.time
report_power > $TOP.power

write -hierarchy -format verilog -output ${TOP}_syn.v

